@@ -1,7 +1,3 @@
-try:
-    import tktooltip
-except ImportError:
-    pass
 import tkinter as tk
 import tkinter.ttk as ttk
 from ctypes import windll, POINTER, Structure, c_bool, sizeof, windll, pointer, c_int
@@ -14,7 +10,7 @@ from tkdev.devresize import DevResize
 from tkdev.devnet import WindowEffect
 from tkdev.devcore import DevAction, DevSysTray
 from tkdev.devdraw import DrawButton
-from tkdev.devpre import DevPreToolbox, DevPreTooltip
+from tkdev.devpre import DevPreToolbox
 import warnings
 
 try:
@@ -815,40 +811,6 @@ class DevSubWindow(tk.Frame):
         self.place(x=0, y=0, width=300, height=300)
 
 
-try:
-    class DevToolTip(tktooltip.ToolTip):
-        def __init__(self, widget: tk.Widget,
-                     msg: str = "",
-                     delay: float = 1.0,
-                     follow: bool = True,
-                     refresh: float = 1.0,
-                     x_offset: int = +10,
-                     y_offset: int = +10,
-                     parent_kwargs: dict = {"bg": "black", "padx": 1, "pady": 1},
-                     foreground: str = "#ffffff", background="#1c1c1c",
-                     **message_kwargs):
-            """
-            本人比较懒，不想写，就用了tkinter-tooltip组件，请不要喷我
-
-            :param widget:
-            :param msg:
-            :param delay:
-            :param follow:
-            :param refresh:
-            :param x_offset:
-            :param y_offset:
-            :param parent_kwargs:
-            :param foreground:
-            :param background:
-            :param message_kwargs:
-            """
-            super(DevToolTip, self).__init__(widget=widget, msg=msg, delay=delay, follow=follow, refresh=refresh,
-                                             x_offset=x_offset, y_offset=y_offset, parent_kwargs=parent_kwargs,
-                                             fg=foreground, bg=background)
-except NameError:
-    pass
-
-
 class DevToast(tk.Toplevel):
     def __init__(self, master: tk.Tk = None,
                  title: str = "Title", message: str = "Message", height: int = 80):
@@ -1016,7 +978,75 @@ class DevToplevel(tk.Toplevel, DevWindow):
         self.iconbitmap(Icon_Empty)
 
 
+class DevTooltip(DevToplevel):
+    def __init__(self, widget: tk.Widget, window: tk.Tk, message: str = "", after: int = 1000, border: bool = True, padding: int = 3, side=tk.CENTER, height: int = 40,
+                 background="#ffffff", foreground="#000000"):
+        super(DevPreTooltip, self).__init__()
+        self.configure(background=background, relief=tk.RAISED, border=1)
+        from tkdev import window_border
+        self._message = ttk.Label(self, background=background, foreground=foreground, text=message, anchor=tk.CENTER)
+        self._message.pack(padx=padding, pady=padding, ipadx=padding, ipady=padding, fill=tk.BOTH, expand=tk.YES)
+        if border:
+            window_border(self)
+        if not border:
+            self.overrideredirect(True)
+        self.withdraw()
+
+        self.widget = widget
+        self.window = window
+        self._height = height
+        self._afterms = after
+        self.side = side
+        self.padding = padding
+
+        self.ison = False
+        self.border = border
+
+        self.widget.bind("<Enter>", lambda evt: self.show())
+        self.widget.bind("<Leave>", lambda evt: self.hide())
+
+        self.geometry(f"{self.widget.winfo_width()}x{self._height}")
+
+    @property
+    def after_ms(self):
+        return self._afterms
+
+    @after_ms.setter
+    def after_ms(self, ms: int = 1000):
+        self._afterms = ms
+
+    @property
+    def message(self):
+        return self.message
+
+    @message.setter
+    def message(self, text: str):
+        self._message.configure(text=text)
+
+    def hide(self):
+        self.ison = False
+        self.window.deiconify()
+        self.withdraw()
+
+    def show(self):
+        self.ison = True
+
+        def on():
+            self.geometry(f"{self.widget.winfo_width()}x{self._height}")
+            if self.ison:
+                if self.side == "center":
+                    if self.border:
+                        self.geometry(
+                            f"+{self.widget.winfo_rootx() - 7}+{self.widget.winfo_rooty() + self.widget.winfo_height() + 5}")
+                    else:
+                        self.geometry(
+                            f"+{self.widget.winfo_rootx()}+{self.widget.winfo_rooty() + self.widget.winfo_height() + 5}")
+                self.deiconify()
+
+        self.after(self._afterms, on)
+
+
 if __name__ == '__main__':
     Window = DevWindow()
-    ToolTip = DevPreTooltip(Window, Window)
+    DevPreTooltip(Window, Window, message="我是一个工具提示", after=0)
     Window.mainloop()
\ No newline at end of file
